==> pyFlaskBootstrap4-0.0.7.tar.gz: pyFlaskBootstrap4-0.0.7/README.md <==
# pyFlaskBootstrap4
Flask + Bootstrap 4 static components and templates for webprojects

[![Documentation Status](https://readthedocs.org/projects/pyflaskbootstrap4/badge/?version=latest)](https://pyflaskbootstrap4.readthedocs.io/en/latest/?badge=latest)
[![pypi](https://img.shields.io/pypi/pyversions/pyFlaskBootstrap4)](https://pypi.org/project/pyFlaskBootstrap4/)
[![Travis (.org)](https://img.shields.io/travis/WolfgangFahl/pyFlaskBootstrap4.svg)](https://travis-ci.org/WolfgangFahl/pyFlaskBootstrap4)
[![Github Actions Build](https://github.com/WolfgangFahl/pyFlaskBootstrap4/workflows/Build/badge.svg?branch=main)](https://github.com/WolfgangFahl/py-sidif/actions?query=workflow%3ABuild+branch%3Amain)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/pyFlaskBootstrap4.svg)](https://github.com/WolfgangFahl/pyFlaskBootstrap4/issues)
[![GitHub issues](https://img.shields.io/github/issues-closed/WolfgangFahl/pyFlaskBootstrap4.svg)](https://github.com/WolfgangFahl/pyFlaskBootstrap4/issues/?q=is%3Aissue+is%3Aclosed)
[![GitHub](https://img.shields.io/github/license/WolfgangFahl/pyFlaskBootstrap4.svg)](https://www.apache.org/licenses/LICENSE-2.0)
[![PyPI Status](https://img.shields.io/pypi/v/pyFlaskBootstrap4.svg)](https://pypi.python.org/pypi/pyFlaskBootstrap4/)

What it is
==========
Flask + Bootstrap 4 static components and templates for webprojects

Installation
============
```bash
pip install pyFlaskBootstrap4
```

Get Sources
===========
```bash
git clone https://github.com/WolfgangFahl/pyFlaskBootstrap4
cd pyFlaskBootstrap4
scripts/install
```

Testing
=======
```bash
scripts/test
```

Usage
=====
see [test cases](https://github.com/WolfgangFahl/pyFlaskBootstrap4/tree/main/tests)

## Documentation
[Wiki](http://wiki.bitplan.com/index.php/PyFlaskBootstrap4)

### Authors
* [Wolfgang Fahl](http://www.bitplan.com/Wolfgang_Fahl)

==> pyFlaskBootstrap4-0.2.4.tar.gz: pyFlaskBootstrap4-0.2.4/README.md <==
# pyFlaskBootstrap4
Flask + Bootstrap 4 static components and templates for webprojects

[![Documentation Status](https://readthedocs.org/projects/pyflaskbootstrap4/badge/?version=latest)](https://pyflaskbootstrap4.readthedocs.io/en/latest/?badge=latest)
[![pypi](https://img.shields.io/pypi/pyversions/pyFlaskBootstrap4)](https://pypi.org/project/pyFlaskBootstrap4/)
[![Travis (.org)](https://img.shields.io/travis/WolfgangFahl/pyFlaskBootstrap4.svg)](https://travis-ci.org/WolfgangFahl/pyFlaskBootstrap4)
[![Github Actions Build](https://github.com/WolfgangFahl/pyFlaskBootstrap4/workflows/Build/badge.svg?branch=main)](https://github.com/WolfgangFahl/pyFlaskBootstrap4/actions?query=workflow%3ABuild+branch%3Amain)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/pyFlaskBootstrap4.svg)](https://github.com/WolfgangFahl/pyFlaskBootstrap4/issues)
[![GitHub issues](https://img.shields.io/github/issues-closed/WolfgangFahl/pyFlaskBootstrap4.svg)](https://github.com/WolfgangFahl/pyFlaskBootstrap4/issues/?q=is%3Aissue+is%3Aclosed)
[![GitHub](https://img.shields.io/github/license/WolfgangFahl/pyFlaskBootstrap4.svg)](https://www.apache.org/licenses/LICENSE-2.0)
[![PyPI Status](https://img.shields.io/pypi/v/pyFlaskBootstrap4.svg)](https://pypi.python.org/pypi/pyFlaskBootstrap4/)

What it is
==========
Flask + Bootstrap 4 static components and templates for webprojects

Installation
============
```bash
pip install pyFlaskBootstrap4
```

Get Sources
===========
```bash
git clone https://github.com/WolfgangFahl/pyFlaskBootstrap4
cd pyFlaskBootstrap4
scripts/install
```

Testing
=======
```bash
scripts/test
```

Usage
=====
see [test cases](https://github.com/WolfgangFahl/pyFlaskBootstrap4/tree/main/tests)

## Documentation
[Wiki](http://wiki.bitplan.com/index.php/PyFlaskBootstrap4)

### Authors
* [Wolfgang Fahl](http://www.bitplan.com/Wolfgang_Fahl)
